@@ -44,6 +44,8 @@ def compile_all():
     # os.system("rcc style.qrc -o style.rcc")
     print("Compiling for PyQt4: style.qrc -> pyqt_style_rc.py")
     os.system("pyrcc4 -py3 style.qrc -o pyqt_style_rc.py")
+    print("Compiling for PyQt5: style.qrc -> pyqt5_style_rc.py")
+    os.system("pyrcc5 style.qrc -o pyqt5_style_rc.py")
     print("Compiling for PySide: style.qrc -> pyside_style_rc.py")
     os.system("pyside-rcc -py3 style.qrc -o pyside_style_rc.py")
 
